<?php

namespace App\DataTables;

use App\Models\UsersKPI;
use Illuminate\Database\Eloquent\Builder as QueryBuilder;
use Yajra\DataTables\EloquentDataTable;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Button;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Html\Editor\Editor;
use Yajra\DataTables\Html\Editor\Fields;
use Yajra\DataTables\Services\DataTable;

class UserKPISDataTable extends DataTable
{
    /**
     * Build DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     * @return \Yajra\DataTables\EloquentDataTable
     */
    public function dataTable(QueryBuilder $query): EloquentDataTable
    {
        return (new EloquentDataTable($query->select('users_kpis.id','users_kpis.kpi_id','users_kpis.user_id','users_kpis.year','users_kpis.month','users_kpis.total_employee_score','users_kpis.created_at')->has('KPI')->has('User')->with('KPI','User')))
            ->editColumn('checkbox',function($kpi){
                return '<div class="custom-control custom-checkbox"><input type="checkbox"  class="custom-control-input kpi-checkbox" value="'.$kpi->id.'" id="selectCheckbox-'.$kpi->id.'"><label class="custom-control-label" for="selectCheckbox-'.$kpi->id.'"></label></div>';
            })
            ->filterColumn('user.name',function($query, $keyword){
                $query->whereHas('User',function($q)use($keyword){
                    return $q->where('name', 'LIKE', "%$keyword%");
                });
            })
            ->filterColumn('k_p_i.name',function($query, $keyword){
                $query->whereHas('KPI',function($q)use($keyword){
                    return $q->where('name', 'LIKE', "%$keyword%");
                });
            })
            ->addColumn('action', function($model){
                $html='<div class="btn-group pull-right">';
                if(PerUser('users_kpis.edit')){
                    $html.='<a href="'.route('users_kpis.edit',['users_kpi'=>$model->id]).'" class="btn btn-sm btn-success"><span class="fadeIn animated bx bx-edit-alt"> </span></a>';
                }
                if(PerUser('users_kpis.destroy')){
                    $html.='<a href="#" class="btn btn-sm btn-danger delete-this" data-id="'.$model->id.'" data-url="'.route('users_kpis.destroy',['users_kpi'=>$model]).'"><span class="fadeIn animated bx bx-trash"> </span></a>';
                }
                $html.='</div>';
                return$html;
            })
                ->editColumn('created_at',function ($model){
                    return $model->created_at->format('Y-m-d H:i:s');
                })

            ->rawColumns(['status','checkbox','action'])
            ->setRowId('id');
    }

    /**
     * Get query source of dataTable.
     *
     * @param \App\Models\UsersKPI $model
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function query(UsersKPI $model): QueryBuilder
    {
        return $model->newQuery();
    }

    /**
     * Optional method if you want to use html builder.
     *
     * @return \Yajra\DataTables\Html\Builder
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
                    ->setTableId('users_kpis')
            ->columns($this->getColumns())
            ->minifiedAjax()
//                    ->dom('Bfrtip')
            ->orderBy(1)
            ->pageLength(10)
            ->lengthMenu([10, 20, 50, 100, 150])
//                    ->buttons(
//                        Button::make('export'),
//                        Button::make('print'),
//                        Button::make('reset'),
//                        Button::make('reload')
//                    )
            ;
    }

    /**
     * Get columns.
     *
     * @return array
     */
    protected function getColumns(): array
    {
        return [
            Column::make('checkbox')
                ->title('<div class="custom-control custom-checkbox"><input type="checkbox" class="custom-control-input" id="selectAllCheckbox"><label class="custom-control-label" for="selectAllCheckbox"></label></div>')
                ->searchable(false)
                ->exportable(false)
                ->printable(false)
                ->width('10px')
                ->orderable(false),
            Column::make('id'),
            Column::make('user.name'),
            Column::make('k_p_i.name'),
            Column::make('year'),
            Column::make('month'),
            Column::make('total_employee_score'),
            Column::make('created_at'),
            Column::computed('action')
                ->exportable(false)
                ->printable(false)
                ->width(60)
                ->addClass('text-center'),
        ];
    }

    /**
     * Get filename for export.
     *
     * @return string
     */
    protected function filename(): string
    {
        return 'UserUserKPIS_' . date('YmdHis');
    }
}
